@@ -1,5 +1,5 @@
 '''wArgsTools
-Author: Mohammed Hossny
+Author: Mo Hossny
 Email: m.hossny@research.deakin.edu.au
 
 This module encapsulates functions and classes to parse args and kwargs of
@@ -18,9 +18,9 @@ Exported Functionalities
 - wArgsHelp: Produces help of all objects using wArgs. 
 - wildArgs: Lite weight and EAGER wArgs encapsulator allows on the spot CLI arg for a selected local variables.
 
-TODO:
-23/04/20 - Adjust error reporting and exception handling outside class factory
-22/04/20 - Add choioces support (e.g. set?)
+## TODO:
+24/04/20 - Clean wArgsCheck and use Levenshtein Distance and argmax for prefixed arg matching
+22/04/20 - Add chooices support (e.g. set?)
 22/04/20 - Add CLI dictionary support (e.g. --dictarg k1:v1 k2:v2 ...)
 22/04/20 - Add Ellipsis support (e.g. f(x=...) -> ???)
 22/04/20 - Allow importing modules for python eval'd args (e.g. --import math, --import_from math pi log sin)
@@ -28,9 +28,11 @@ TODO:
 04/01/20 - Fix mutability of unknown_args
 10/01/20 - Add custom help formatter
 
-DONE:
+## DONE:
+24/06/20 - Fixed a bug with prefixed args reportede as unknown args (Needs more work. Chk TODOs)
 22/04/20 - Fixed EvalArgParseAction cannot access membeers of loaded modules (e.g. nn.MSE)
-21/04/20 - Fixed boolean args defalted to True. Now defaults to False and a `no` prefix is added to arg name (e.g. Flag -> --noFlag)
+21/04/20 - Fixed boolean args defalted to True. Now defaults to False and a `no` prefix is added to arg name (e.g. Flag -> --noFl\
+ag)
 21/04/20 - Add docstring support
 20/04/20 - Supports inheritance
 20/04/20 - fixed inheritance order (reversed(callableobj.mro()))
@@ -38,7 +40,7 @@ DONE:
 '''
 import sys
 
-__VERSION__ = '0.0.8'
+__VERSION__ = '0.1.0'
 print(f'wArgsTools v{__VERSION__} is still under development!!!!\n\n', file=sys.stderr)
 
 from .core import EvalArgParseAction
